@@ -26,7 +26,8 @@
 # *
 # **************************************************************************
 
-from pyworkflow.tests import *
+from pyworkflow.tests import BaseTest, DataSet, setupTestProject
+
 from pwem.protocols import ProtImportMicrographs, ProtImportParticles
 from pyworkflow.utils import magentaStr
 
@@ -107,11 +108,10 @@ class TestCtffind4(TestBase):
         self.launchProtocol(protCTF, wait=True)
         self.assertIsNotNone(protCTF.outputCTF, "SetOfCTF has not been produced.")
 
-        valuesList = [[24067, 23587, 58], [22373, 22039, 66], [22653, 22480, 5]]
+        valuesList = [[24067, 23587], [22373, 22039], [22653, 22480]]
         for ctfModel, values in zip(protCTF.outputCTF, valuesList):
             self.assertAlmostEquals(ctfModel.getDefocusU(), values[0], delta=1000)
             self.assertAlmostEquals(ctfModel.getDefocusV(), values[1], delta=1000)
-            self.assertAlmostEquals(ctfModel.getDefocusAngle(), values[2], delta=10)
 
 
 class TestFindParticles(TestBase):
